/**
 * \file
 *
 * Test harness for functions generated from Simulink.
 *
 * \req
 * Internal request.
 *
 * \note
 * Besides being a test harness for SimuLink S-Functions, this 
 * is a test bed for Doxygen mark-up. 
 */

#include <stdio.h>
#include "Undertest.h"

typedef unsigned char UINT8;

/** Kinds of ports */
enum PortType {
	Input,
	Output,
	IO
};

/** IO Descriptor */
struct Port {
	enum PortType type;  ///< Input, Output or IO
	UINT8         index; ///< Internal reference
};

/** IO Descriptor */
typedef struct Port CommPort;

/** Current active communications port */
CommPort Communication;

/** Correction descriptor */
typedef struct {
	UINT16 gamma; ///< correction factor \pre 0..255=0..100 %
	UINT16 theta; ///< skew angle
} Correction;


/// Format for displaying OutPort.
/// Formats the Port and Gain values for display.
char OutPort[] = "OutPort: %d\nGain: %d\n";

/// Data input format.
/// Used to extract the Port and Gain values from the input.
char DataIn[] = "%d %d"

Correction Shim; ///< Correction Factor.

/**
 * Basic test harness function. Set inputs and read outputs of 
 * the function under test. 
 *
 * @return TRUE if successful.
 */
int Test(
	UINT8 InVal,    ///< [in] Input value for function under test. @b Preconditions 0..150
	char  OutFormat ///< [in] OutFormat Format for parsing OutPort string.
	)
{
    /// \misra
    /// Used in diagnostic interface \@ __LINE__
	/// \bug
	/// Doxygen's preprocessor did not expand the line reference macro
    printf("This is a test.\n");
    InPort = InVal;
    printf("InPort: %d\n", (int)InPort); /** \change{1-3} Simplify display format. */
    Undertest();
    printf("OutPort: %d\n", (int)OutPort);
    /// \bug
    /// Doxygen alias, below, expanded incorectly - got 1.3, expected 1.2
    printf("gain: %d\n", (int)Gain_002); /** \change{1-2} Display an internal global variable. */
    return 1;
}

/**
 * Basic test harness function. Set inputs and read outputs of
 * the function under test. 
 *
 * \param [in] OutPort Format for writing OutPort string.
 *
 * @return Always 1, at this time.
 */
int main(void)
{
    /// \misra
    /// Used in diagnostic interface \@ __LINE__
    printf("This is a test.\n");
    Test(19, OutPort);
    return 1;
}

